Package: rixmp
Type: Package
Title: R Interface to the IX Modeling Platform
Version: 3.2.0.9000
Authors@R: c(
    person("Adriano", "Vinca", email = "vinca@iiasa.ac.at",
           role = c("aut", "cre")),
    person(c("Paul", "Natsuo"), "Kishimoto", email = "kishimot@iiasa.ac.at",
           role = "ctb"),
    person("Matthew", "Gidden", role = "aut"))
Description: The ix modeling platform (ixmp) is a data warehouse for
    high-powered scenario analysis, with interfaces to Python and R for
    efficient scientific workflows and effective data pre- and post-processing,
    and a structured database backend for version-controlled data management.
    This package allows R user to use code developed in Python and interact
    with the ix modeling platform.
Depends:
    R (>= 3.3.0),
    reticulate
Suggests:
    testthat
License: Apache License 2.0
URL: https://github.com/iiasa/ixmp
BugReports: https://github.com/iiasa/ixmp/issues
Encoding: UTF-8
RoxygenNote: 7.0.2
Collate:
    'init_rixmp.R'
    'adapt_to_ret.R'
