# rixmp.legacy
R package for ix modeling platform (ixmp)

The ix modeling platform (ixmp) is a data warehouse for high-powered scenario analysis, with 
interfaces to Python and R for efficient scientific workflows and effective data pre- and post-processing, 
and a structured database backend for version-controlled data management.

Can be integrated with the |MESSAGEix| Integrated Assessment model and other numerical models
http://MESSAGEix.iiasa.ac.at

References

Daniel Huppmann, Matthew Gidden, Oliver Fricko, Peter Kolp, Clara Orthofer,
  Michael Pimmer, Nikolay Kushin, Adriano Vinca, Alessio Mastrucci,
  Keywan Riahi, and Volker Krey.
  "The |MESSAGEix| Integrated Assessment Model and the ix modeling platform".
  *Environmental Modelling & Software* 112:143-156, 2019. 
  doi: [10.1016/j.envsoft.2018.11.012](https://doi.org/10.1016/j.envsoft.2018.11.012)
  electronic pre-print available at
  [pure.iiasa.ac.at/15157/](https://pure.iiasa.ac.at/15157/).

