- Daniel Huppmann,
  [@danielhuppmann](https://github.com/danielhuppmann),
  [iiasa](http://www.iiasa.ac.at/staff/huppmann)
- Matthew Gidden,
  [@gidden](https://github.com/gidden),
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=gidden),
  [web](http://mattgidden.com)
- Volker Krey,
  [@volker-krey](https://github.com/volker-krey),
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=krey)
- Oliver Fricko, [@OFR-IIASA](https://github.com/OFR-IIASA)
- Peter Kolp,
  [@peterkolp](https://github.com/peterkolp/),
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=kolp)
- Paul Natsuo Kishimoto,
  [@khaeru](https://github.com/khaeru)
  [web](https://paul.kishimoto.name)
- Nikolay Kushin,
  [@zikolach](https://github.com/zikolach)
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=kushin)
- Michael Pimmer,
  [@fonfon](https://github.com/fonfon),
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=pimmer)
- Adriano Vinca,
  [@adrivinca](https://github.com/adrivinca),
  [iiasa](http://www.iiasa.ac.at/staff/staff.php?type=auto&visibility=visible&search=true&login=vinca)
